==> huaweicloudsdkrds-3.0.79-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/list_slow_log_file_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListSlowLogFileResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'list': 'list[SlowLogFile]',
        'total_count': 'int'
    }

    attribute_map = {
        'list': 'list',
        'total_count': 'total_count'
    }

    def __init__(self, list=None, total_count=None):
        """ListSlowLogFileResponse - a model defined in huaweicloud sdk"""
        
        super(ListSlowLogFileResponse, self).__init__()

        self._list = None
        self._total_count = None
        self.discriminator = None

        if list is not None:
            self.list = list
        if total_count is not None:
            self.total_count = total_count

    @property
    def list(self):
        """Gets the list of this ListSlowLogFileResponse.


        :return: The list of this ListSlowLogFileResponse.
        :rtype: list[SlowLogFile]
        """
        return self._list

    @list.setter
    def list(self, list):
        """Sets the list of this ListSlowLogFileResponse.


        :param list: The list of this ListSlowLogFileResponse.
        :type: list[SlowLogFile]
        """
        self._list = list

    @property
    def total_count(self):
        """Gets the total_count of this ListSlowLogFileResponse.

        文件总数。

        :return: The total_count of this ListSlowLogFileResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ListSlowLogFileResponse.

        文件总数。

        :param total_count: The total_count of this ListSlowLogFileResponse.
        :type: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSlowLogFileResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrds-3.0.86-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/list_slow_log_file_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListSlowLogFileResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'list': 'list[SlowLogFile]',
        'total_count': 'int'
    }

    attribute_map = {
        'list': 'list',
        'total_count': 'total_count'
    }

    def __init__(self, list=None, total_count=None):
        """ListSlowLogFileResponse

        The model defined in huaweicloud sdk

        :param list: 
        :type list: list[:class:`huaweicloudsdkrds.v3.SlowLogFile`]
        :param total_count: 文件总数。
        :type total_count: int
        """
        
        super(ListSlowLogFileResponse, self).__init__()

        self._list = None
        self._total_count = None
        self.discriminator = None

        if list is not None:
            self.list = list
        if total_count is not None:
            self.total_count = total_count

    @property
    def list(self):
        """Gets the list of this ListSlowLogFileResponse.


        :return: The list of this ListSlowLogFileResponse.
        :rtype: list[:class:`huaweicloudsdkrds.v3.SlowLogFile`]
        """
        return self._list

    @list.setter
    def list(self, list):
        """Sets the list of this ListSlowLogFileResponse.


        :param list: The list of this ListSlowLogFileResponse.
        :type list: list[:class:`huaweicloudsdkrds.v3.SlowLogFile`]
        """
        self._list = list

    @property
    def total_count(self):
        """Gets the total_count of this ListSlowLogFileResponse.

        文件总数。

        :return: The total_count of this ListSlowLogFileResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ListSlowLogFileResponse.

        文件总数。

        :param total_count: The total_count of this ListSlowLogFileResponse.
        :type total_count: int
        """
        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListSlowLogFileResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
